/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 2.0.0.00
// Release Date: Tuesday, December 20, 2016 2:00 PM
//#############################################################################
#include <LCD.h>
#include "LcdDriver/kitronix320x240x16_ssd2119_spi.h"
#include "images/images.h"
#include <math.h>

//****************************************************************************************
// Globals
//****************************************************************************************
Slider_PositionIndicatorV VolumeSlider_positionIndicator =
{
    .xMin = 135,
    .xMax = 304,
    .y = 155,
    .height = 31
};

Slider_PositionIndicatorV GeneralPurposeSlider_positionIndicator =
{
    .xMin = 33,
    .xMax = 280,
    .y = 16,
    .height = 0
};

//Phone Panel Buttons
Graphics_ImageButton _1_Key;
Graphics_ImageButton _2_Key;
Graphics_ImageButton _3_Key;
Graphics_ImageButton _4_Key;
Graphics_ImageButton _5_Key;
Graphics_ImageButton _6_Key;
Graphics_ImageButton _7_Key;
Graphics_ImageButton _8_Key;
Graphics_ImageButton _9_Key;
Graphics_ImageButton _Star_Key;
Graphics_ImageButton _0_Key;
Graphics_ImageButton _Pound_Key;
Graphics_ImageButton *numericKeypad[12] =
{ &_1_Key, &_4_Key, &_7_Key, &_Star_Key, &_2_Key, &_5_Key, &_8_Key, &_0_Key,
  &_3_Key, &_6_Key, &_9_Key, &_Pound_Key };

Graphics_ImageButton EndCall_Key;
Graphics_ImageButton Headset_Key;
Graphics_ImageButton Mute_Key;
Graphics_ImageButton Speaker_Key;
Graphics_ImageButton *modeKeypad[4] =
{ &EndCall_Key, &Headset_Key, &Mute_Key, &Speaker_Key };

Graphics_ImageButton Volume_Slider;
Graphics_ImageButton General_Slider;

Graphics_Rectangle proximity;
Graphics_Rectangle GuardChannel_textBackground =
{
    .xMin = GUARD_CHANNEL_ACTIVE_TEXT_XMIN,
    .xMax = GUARD_CHANNEL_ACTIVE_TEXT_XMAX,
    .yMin = GUARD_CHANNEL_ACTIVE_TEXT_YMIN,
    .yMax = GUARD_CHANNEL_ACTIVE_TEXT_YMAX
};

// Graphic library context
Graphics_Context g_sContext;

//****************************************************************************************
// Function Prototypes
//****************************************************************************************
void LCD_initDemoImages(void);

void LCD_init(void)
{
    // LCD setup using Graphics Library API calls
    Kitronix320x240x16_SSD2119Init();
    Graphics_initContext(&g_sContext, &g_sKitronix320x240x16_SSD2119);
    Graphics_setBackgroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_setFont(&g_sContext, &g_sFontCmss20b);
    Graphics_clearDisplay(&g_sContext);

    // Initialize graphics image structures
    LCD_initDemoImages();
}

void LCD_initDemoImages(void)
{
    _1_Key.xPosition = NUMERIC_KEYPAD_COLUMN1_X;
    _1_Key.yPosition = NUMERIC_KEYPAD_ROW1_Y;
    _1_Key.borderWidth = 1;
    _1_Key.selected = false;
    _1_Key.imageWidth = Button_18BPP_COMP_RLE8.xSize;
    _1_Key.imageHeight = Button_18BPP_COMP_RLE8.ySize;
    _1_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _1_Key.selectedColor = GRAPHICS_COLOR_RED;
    _1_Key.image = &Button_18BPP_COMP_RLE8;

    _2_Key.xPosition = NUMERIC_KEYPAD_COLUMN2_X;
    _2_Key.yPosition = NUMERIC_KEYPAD_ROW1_Y;
    _2_Key.borderWidth = 1;
    _2_Key.selected = false;
    _2_Key.imageWidth = Button_28BPP_COMP_RLE8.xSize;
    _2_Key.imageHeight = Button_28BPP_COMP_RLE8.ySize;
    _2_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _2_Key.selectedColor = GRAPHICS_COLOR_RED;
    _2_Key.image = &Button_28BPP_COMP_RLE8;

    _3_Key.xPosition = NUMERIC_KEYPAD_COLUMN3_X;
    _3_Key.yPosition = NUMERIC_KEYPAD_ROW1_Y;
    _3_Key.borderWidth = 1;
    _3_Key.selected = false;
    _3_Key.imageWidth = Button_38BPP_COMP_RLE8.xSize;
    _3_Key.imageHeight = Button_38BPP_COMP_RLE8.ySize;
    _3_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _3_Key.selectedColor = GRAPHICS_COLOR_RED;
    _3_Key.image = &Button_38BPP_COMP_RLE8;

    _4_Key.xPosition = NUMERIC_KEYPAD_COLUMN1_X;
    _4_Key.yPosition = NUMERIC_KEYPAD_ROW2_Y;
    _4_Key.borderWidth = 1;
    _4_Key.selected = false;
    _4_Key.imageWidth = Button_48BPP_COMP_RLE8.xSize;
    _4_Key.imageHeight = Button_48BPP_COMP_RLE8.ySize;
    _4_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _4_Key.selectedColor = GRAPHICS_COLOR_RED;
    _4_Key.image = &Button_48BPP_COMP_RLE8;

    _5_Key.xPosition = NUMERIC_KEYPAD_COLUMN2_X;
    _5_Key.yPosition = NUMERIC_KEYPAD_ROW2_Y;
    _5_Key.borderWidth = 1;
    _5_Key.selected = false;
    _5_Key.imageWidth = Button_58BPP_COMP_RLE8.xSize;
    _5_Key.imageHeight = Button_58BPP_COMP_RLE8.ySize;
    _5_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _5_Key.selectedColor = GRAPHICS_COLOR_RED;
    _5_Key.image = &Button_58BPP_COMP_RLE8;

    _6_Key.xPosition = NUMERIC_KEYPAD_COLUMN3_X;
    _6_Key.yPosition = NUMERIC_KEYPAD_ROW2_Y;
    _6_Key.borderWidth = 1;
    _6_Key.selected = false;
    _6_Key.imageWidth = Button_68BPP_COMP_RLE8.xSize;
    _6_Key.imageHeight = Button_68BPP_COMP_RLE8.ySize;
    _6_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _6_Key.selectedColor = GRAPHICS_COLOR_RED;
    _6_Key.image = &Button_68BPP_COMP_RLE8;

    _7_Key.xPosition = NUMERIC_KEYPAD_COLUMN1_X;
    _7_Key.yPosition = NUMERIC_KEYPAD_ROW3_Y;
    _7_Key.borderWidth = 1;
    _7_Key.selected = false;
    _7_Key.imageWidth = Button_78BPP_COMP_RLE8.xSize;
    _7_Key.imageHeight = Button_78BPP_COMP_RLE8.ySize;
    _7_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _7_Key.selectedColor = GRAPHICS_COLOR_RED;
    _7_Key.image = &Button_78BPP_COMP_RLE8;

    _8_Key.xPosition = NUMERIC_KEYPAD_COLUMN2_X;
    _8_Key.yPosition = NUMERIC_KEYPAD_ROW3_Y;
    _8_Key.borderWidth = 1;
    _8_Key.selected = false;
    _8_Key.imageWidth = Button_88BPP_COMP_RLE8.xSize;
    _8_Key.imageHeight = Button_88BPP_COMP_RLE8.ySize;
    _8_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _8_Key.selectedColor = GRAPHICS_COLOR_RED;
    _8_Key.image = &Button_88BPP_COMP_RLE8;

    _9_Key.xPosition = NUMERIC_KEYPAD_COLUMN3_X;
    _9_Key.yPosition = NUMERIC_KEYPAD_ROW3_Y;
    _9_Key.borderWidth = 1;
    _9_Key.selected = false;
    _9_Key.imageWidth = Button_98BPP_COMP_RLE8.xSize;
    _9_Key.imageHeight = Button_98BPP_COMP_RLE8.ySize;
    _9_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _9_Key.selectedColor = GRAPHICS_COLOR_RED;
    _9_Key.image = &Button_98BPP_COMP_RLE8;

    _Star_Key.xPosition = NUMERIC_KEYPAD_COLUMN1_X;
    _Star_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    _Star_Key.borderWidth = 1;
    _Star_Key.selected = false;
    _Star_Key.imageWidth = Button_Star8BPP_COMP_RLE8.xSize;
    _Star_Key.imageHeight = Button_Star8BPP_COMP_RLE8.ySize;
    _Star_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _Star_Key.selectedColor = GRAPHICS_COLOR_RED;
    _Star_Key.image = &Button_Star8BPP_COMP_RLE8;

    _0_Key.xPosition = NUMERIC_KEYPAD_COLUMN2_X;
    _0_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    _0_Key.borderWidth = 1;
    _0_Key.selected = false;
    _0_Key.imageWidth = Button_08BPP_COMP_RLE8.xSize;
    _0_Key.imageHeight = Button_08BPP_COMP_RLE8.ySize;
    _0_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _0_Key.selectedColor = GRAPHICS_COLOR_RED;
    _0_Key.image = &Button_08BPP_COMP_RLE8;

    _Pound_Key.xPosition = NUMERIC_KEYPAD_COLUMN3_X;
    _Pound_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    _Pound_Key.borderWidth = 1;
    _Pound_Key.selected = false;
    _Pound_Key.imageWidth = Button_Pound8BPP_COMP_RLE8.xSize;
    _Pound_Key.imageHeight = Button_Pound8BPP_COMP_RLE8.ySize;
    _Pound_Key.borderColor = GRAPHICS_COLOR_WHITE;
    _Pound_Key.selectedColor = GRAPHICS_COLOR_RED;
    _Pound_Key.image = &Button_Pound8BPP_COMP_RLE8;

    EndCall_Key.xPosition = 145;
    EndCall_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    EndCall_Key.borderWidth = 1;
    EndCall_Key.selected = false;
    EndCall_Key.imageWidth = Button_EndCall8BPP_COMP_RLE8.xSize;
    EndCall_Key.imageHeight = Button_EndCall8BPP_COMP_RLE8.ySize;
    EndCall_Key.borderColor = GRAPHICS_COLOR_WHITE;
    EndCall_Key.selectedColor = GRAPHICS_COLOR_RED;
    EndCall_Key.image = &Button_EndCall8BPP_COMP_RLE8;

    Headset_Key.xPosition = 185;
    Headset_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    Headset_Key.borderWidth = 1;
    Headset_Key.selected = false;
    Headset_Key.imageWidth = Button_Headset8BPP_COMP_RLE8.xSize;
    Headset_Key.imageHeight = Button_Headset8BPP_COMP_RLE8.ySize;
    Headset_Key.borderColor = GRAPHICS_COLOR_WHITE;
    Headset_Key.selectedColor = GRAPHICS_COLOR_RED;
    Headset_Key.image = &Button_Headset8BPP_COMP_RLE8;

    Mute_Key.xPosition = 225;
    Mute_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    Mute_Key.borderWidth = 1;
    Mute_Key.selected = false;
    Mute_Key.imageWidth = Button_Mute8BPP_COMP_RLE8.xSize;
    Mute_Key.imageHeight = Button_Mute8BPP_COMP_RLE8.ySize;
    Mute_Key.borderColor = GRAPHICS_COLOR_WHITE;
    Mute_Key.selectedColor = GRAPHICS_COLOR_RED;
    Mute_Key.image = &Button_Mute8BPP_COMP_RLE8;

    Speaker_Key.xPosition = 265;
    Speaker_Key.yPosition = NUMERIC_KEYPAD_ROW4_Y;
    Speaker_Key.borderWidth = 1;
    Speaker_Key.selected = false;
    Speaker_Key.imageWidth = Button_Speaker8BPP_COMP_RLE8.xSize;
    Speaker_Key.imageHeight = Button_Speaker8BPP_COMP_RLE8.ySize;
    Speaker_Key.borderColor = GRAPHICS_COLOR_WHITE;
    Speaker_Key.selectedColor = GRAPHICS_COLOR_RED;
    Speaker_Key.image = &Button_Speaker8BPP_COMP_RLE8;

    Volume_Slider.xPosition = 130;
    Volume_Slider.yPosition = 155;
    Volume_Slider.borderWidth = 1;
    Volume_Slider.selected = false;
    Volume_Slider.imageWidth = Slider_Volume4BPP_COMP_RLE4.xSize;
    Volume_Slider.imageHeight = Slider_Volume4BPP_COMP_RLE4.ySize;
    Volume_Slider.borderColor = GRAPHICS_COLOR_WHITE;
    Volume_Slider.selectedColor = GRAPHICS_COLOR_RED;
    Volume_Slider.image = &Slider_Volume4BPP_COMP_RLE4;

    General_Slider.xPosition = 30;
    General_Slider.yPosition = 15;
    General_Slider.borderWidth = 1;
    General_Slider.selected = false;
    General_Slider.imageWidth = Slider_GeneralPurpose4BPP_COMP_RLE4.xSize;
    General_Slider.imageHeight = Slider_GeneralPurpose4BPP_COMP_RLE4.ySize;
    General_Slider.borderColor = GRAPHICS_COLOR_WHITE;
    General_Slider.selectedColor = GRAPHICS_COLOR_RED;
    General_Slider.image = &Slider_GeneralPurpose4BPP_COMP_RLE4;

    proximity.xMin = 0;
    proximity.yMin = 0;
    proximity.xMax = 319;
    proximity.yMax = 239;
}

extern void LCD_drawNumKeypad(Demo_ButtonTouchType* numButtons)
{
    // Update button images based on new state
    uint8_t index;
    for(index = 0; index < 12; index++)
    {
        if(numButtons[index].touch && !numButtons[index].prevTouch)
        {
            Graphics_drawSelectedImageButton(&g_sContext, numericKeypad[index]);
        }
        else if(!numButtons[index].touch && numButtons[index].prevTouch)
        {
            Graphics_drawImageButton(&g_sContext, numericKeypad[index]);
        }
    }
}

extern void LCD_drawModeKeypad(Demo_ButtonTouchType* modeButtons)
{
    // Update "End Call" button
    if(modeButtons[0].touch && !modeButtons[0].prevTouch)
    {
        Graphics_drawSelectedImageButton(&g_sContext, modeKeypad[0]);
    }
    else if(!modeButtons[0].touch && modeButtons[0].prevTouch)
    {
        Graphics_drawImageButton(&g_sContext, modeKeypad[0]);
    }

    // Update rest of mode buttons
    uint8_t index;
    for(index = 1; index < 4; index++)
    {
        if(modeButtons[index].touch && !modeButtons[index].prevTouch)
        {
            modeButtons[index].state = modeButtons[index].state ^ true;
            if(modeButtons[index].state)
            {
                Graphics_drawSelectedImageButton(&g_sContext,
                                                 modeKeypad[index]);
            }
            else
            {
                Graphics_drawImageButton(&g_sContext, modeKeypad[index]);
            }
        }
    }
}

extern void LCD_drawWheelButton(Demo_ButtonTouchType* wheelButton)
{
    if(wheelButton->touch && !wheelButton->prevTouch)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
        Graphics_fillCircle(&g_sContext, 215, 101, 13);
    }
    else if(!wheelButton->touch && wheelButton->prevTouch)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
        Graphics_fillCircle(&g_sContext, 215, 101, 13);
    }
}

extern void LCD_drawVolumeSlider(Demo_SliderAndWheelType* volumeSlider)
{
    // Convert to position on LCD
    int32_t LCD_position = VolumeSlider_positionIndicator.xMin +
                           ((VolumeSlider_positionIndicator.xMax -
                             VolumeSlider_positionIndicator.xMin) *
                            volumeSlider->position) / 100;

    if(volumeSlider->position > volumeSlider->prevPosition)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
        int32_t i;
        int8_t j = 0;
        for(i = VolumeSlider_positionIndicator.xMin; i < LCD_position + 1;
            i +=
                (VolumeSlider_positionIndicator.xMax -
                 VolumeSlider_positionIndicator.xMin) / 14)
        {
            Graphics_drawLineH(&g_sContext, i, LCD_position, 178 - j);
            j++;
        }
    }
    else
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
        uint32_t deltaWidth =
            ((VolumeSlider_positionIndicator.xMax -
              VolumeSlider_positionIndicator.xMin) / 14);
        int32_t i;
        int8_t j = 0;
        for(i = VolumeSlider_positionIndicator.xMax; i > LCD_position; i--)
        {
            j = VolumeSlider_positionIndicator.xMax / deltaWidth -
                (i - 3) / deltaWidth;
            Graphics_drawLineV(&g_sContext, i,
                               VolumeSlider_positionIndicator.y + 9 + j,
                               VolumeSlider_positionIndicator.y - 8 +
                               VolumeSlider_positionIndicator.height);
        }
    }
}

extern void LCD_drawGPSlider(Demo_SliderAndWheelType* gpSlider)
{
    int32_t LCD_position = GeneralPurposeSlider_positionIndicator.xMin +
                           ((GeneralPurposeSlider_positionIndicator.xMax -
                             GeneralPurposeSlider_positionIndicator.xMin) *
                            gpSlider->position) / 100;
    int32_t LCD_prevPosition = GeneralPurposeSlider_positionIndicator.xMin +
                               ((GeneralPurposeSlider_positionIndicator.xMax -
                                 GeneralPurposeSlider_positionIndicator.xMin) *
                                gpSlider->prevPosition) / 100;

    // Clear old line
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y - 4);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y - 3);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y - 2);

    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 1);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 2);

    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 28);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 29);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 30);

    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 33);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 34);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 2, LCD_prevPosition + 2,
                       GeneralPurposeSlider_positionIndicator.y + 35);

    // Draw new line
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y - 4);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y - 3);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y - 2);

    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 1);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 2);

    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 28);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 29);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 30);

    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 33);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 34);
    Graphics_drawLineH(&g_sContext, LCD_position - 2, LCD_position + 2,
                       GeneralPurposeSlider_positionIndicator.y + 35);
}

extern void LCD_drawScrollWheel(Demo_SliderAndWheelType* scrollWheel)
{
    if(scrollWheel->position != scrollWheel->prevPosition)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
        double rads =
            (double)((float)(scrollWheel->prevPosition * 2 *
                             _PI) / (float)RESOLUTION - _PI / (float)2);
        int32_t x = (int32_t)((double)34 * cos(rads)) + 215;
        int32_t y = (int32_t)((double)34 * sin(rads)) + 101;
        Graphics_fillCircle(&g_sContext, x, y, 8);

        // Update Position Indicator on LCD
        if(scrollWheel->position != 0xFFFF)
        {
            Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
            rads =
                (double)((float)(scrollWheel->position * 2 *
                                 _PI) / (float)RESOLUTION - _PI / (float)2);
            x = (int32_t)((double)34 * cos(rads)) + 215;
            y = (int32_t)((double)34 * sin(rads)) + 101;
            Graphics_fillCircle(&g_sContext, x, y, 8);
        }
    }
}

extern void LCD_drawGuardChannel(Demo_GuardChannelState* guard)
{
    if(guard->proximity && !guard->prevProximity)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_YELLOW);
        Graphics_drawRectangle(&g_sContext, &proximity);
    }
    else if(!guard->proximity && guard->prevProximity)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
        Graphics_drawRectangle(&g_sContext, &proximity);
    }

    if(guard->touch && !guard->prevTouch)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
        Graphics_fillRectangle(&g_sContext, &GuardChannel_textBackground);
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
        Graphics_drawStringCentered(&g_sContext, "Guard Channel Active",
                                    AUTO_STRING_LENGTH,
                                    GUARD_CHANNEL_ACTIVE_TEXT_XSTART,
                                    GUARD_CHANNEL_ACTIVE_TEXT_YSTART,
                                    TRANSPARENT_TEXT);
    }
}

extern void LCD_drawSavedState(Demo_ButtonTouchType* modeButtons,
                               Demo_SliderAndWheelType* volumeSlider,
                               Demo_SliderAndWheelType* gpSlider)
{
    // Clear display
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_clearDisplay(&g_sContext);

    // Draw Numeric Keypad
    uint8_t buttonIndex;
    for(buttonIndex = 0; buttonIndex < 12; buttonIndex++)
    {
        Graphics_drawImageButton(&g_sContext, numericKeypad[buttonIndex]);
    }

    // Draw mode keypad
    Graphics_drawImageButton(&g_sContext, modeKeypad[0]);
    for(buttonIndex = 1; buttonIndex < 4; buttonIndex++)
    {
        if(modeButtons[buttonIndex].state)
        {
            Graphics_drawSelectedImageButton(&g_sContext,
                                             modeKeypad[buttonIndex]);
        }
        else
        {
            Graphics_drawImageButton(&g_sContext, modeKeypad[buttonIndex]);
        }
    }

    // Draw Volume Slider
    volumeSlider->prevPosition = 0;
    Graphics_drawImageButton(&g_sContext, &Volume_Slider);
    LCD_drawVolumeSlider(volumeSlider);

    // Draw general slider
    Graphics_drawImageButton(&g_sContext, &General_Slider);
    LCD_drawGPSlider(gpSlider);

    // Draw wheel in 3 parts
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
    Graphics_fillCircle(&g_sContext, 215, 101, 42);
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_fillCircle(&g_sContext, 215, 101, 24);
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
    Graphics_fillCircle(&g_sContext, 215, 101, 13);
}
