/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 2.0.0.00
// Release Date: Tuesday, December 20, 2016 2:00 PM
//#############################################################################

//*******************************************************************************
//! \file  LCD.c
//
//*******************************************************************************

//*****************************************************************************
// Includes
//*****************************************************************************
#include <LCD.h>
#include "LcdDriver/kitronix320x240x16_ssd2119_spi.h"
#include "images.h"
#include <math.h>

//****************************************************************************************
// Globals
//****************************************************************************************
LCD_ButtonImage numKeypadButtons[NUMERIC_KEYPAD_BUTTON_COUNT];
LCD_ButtonImage modeKeypadButtons[MODE_KEYPAD_BUTTON_COUNT];
LCD_ButtonImage wheelButton;
LCD_SliderImage volumeSlider;
LCD_SliderImage generalPurposeSlider;
LCD_WheelImage scrollWheel;
LCD_GuardChannelImage guardChannel;
LCD_DemoState demoState;

LCD_SliderPositionIndicator VolumeSlider_positionIndicator =
{
    .xMin = 135,
    .xMax = 304,
    .y = 155,
    .height = 31
};

LCD_SliderPositionIndicator GeneralPurposeSlider_positionIndicator =
{
    .xMin = 33,
    .xMax = 280,
    .y = 16,
    .height = 0
};

Graphics_Rectangle proximity =
{
    .xMin = 0,
    .yMin = 0,
    .xMax = 319,
    .yMax = 239
};

Graphics_Rectangle GuardChannel_textBackground =
{
    .xMin = GUARD_CHANNEL_ACTIVE_TEXT_XMIN,
    .xMax = GUARD_CHANNEL_ACTIVE_TEXT_XMAX,
    .yMin = GUARD_CHANNEL_ACTIVE_TEXT_YMIN,
    .yMax = GUARD_CHANNEL_ACTIVE_TEXT_YMAX
};

// Graphic library context
Graphics_Context g_sContext;

//****************************************************************************************
// Function Prototypes
//****************************************************************************************
extern void Kitronix320x240x16_SSD2119PixelDrawImageDMA(void *pvDisplayData,
                                                        int16_t x,
                                                        int16_t y,
                                                        int16_t count,
                                                        uint16_t frameHorizontalSize,
                                                        uint8_t *puint8Data);

void LCD_initButtonImage(LCD_ButtonImage *button,
                         int16_t x,
                         int16_t y,
                         uint16_t pixels,
                         uint16_t width,
                         uint8_t *untouchedImage,
                         uint8_t *touchedImage);

void LCD_initSliderImage(LCD_SliderImage *slider,
                         int16_t x,
                         int16_t y,
                         uint16_t pixels,
                         uint16_t width,
                         uint8_t *image);

void LCD_initGuardChannelImage(LCD_GuardChannelImage *guard,
                               Graphics_Rectangle *prox,
                               Graphics_Rectangle *activeBackground,
                               int32_t x,
                               int32_t y);

void LCD_initDemoState(LCD_DemoState *state);

void LCD_init(void)
{
    // LCD setup using Graphics Library API calls
    Kitronix320x240x16_SSD2119Init();
    Graphics_initContext(&g_sContext, &g_sKitronix320x240x16_SSD2119);
    Graphics_setBackgroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_clearDisplay(&g_sContext);
    Graphics_setFont(&g_sContext, &g_sFontCmss20b);

    // Initialize array of numeric keypad buttons
    LCD_initButtonImage(&numKeypadButtons[0], NUMERIC_KEYPAD_COLUMN1_X,
                        NUMERIC_KEYPAD_ROW1_Y, Button1Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button1Untouched[0],
                        (uint8_t *)&Button1Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[1], NUMERIC_KEYPAD_COLUMN1_X,
                        NUMERIC_KEYPAD_ROW2_Y, Button4Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button4Untouched[0],
                        (uint8_t *)&Button4Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[2], NUMERIC_KEYPAD_COLUMN1_X,
                        NUMERIC_KEYPAD_ROW3_Y, Button7Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button7Untouched[0],
                        (uint8_t *)&Button7Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[3], NUMERIC_KEYPAD_COLUMN1_X,
                        NUMERIC_KEYPAD_ROW4_Y, ButtonStarUntouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&ButtonStarUntouched[0],
                        (uint8_t *)&ButtonStarTouched[0]);

    LCD_initButtonImage(&numKeypadButtons[4], NUMERIC_KEYPAD_COLUMN2_X,
                        NUMERIC_KEYPAD_ROW1_Y, Button2Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button2Untouched[0],
                        (uint8_t *)&Button2Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[5], NUMERIC_KEYPAD_COLUMN2_X,
                        NUMERIC_KEYPAD_ROW2_Y, Button5Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button5Untouched[0],
                        (uint8_t *)&Button5Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[6], NUMERIC_KEYPAD_COLUMN2_X,
                        NUMERIC_KEYPAD_ROW3_Y, Button8Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button8Untouched[0],
                        (uint8_t *)&Button8Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[7], NUMERIC_KEYPAD_COLUMN2_X,
                        NUMERIC_KEYPAD_ROW4_Y, Button0Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button0Untouched[0],
                        (uint8_t *)&Button0Touched[0]);

    LCD_initButtonImage(&numKeypadButtons[8], NUMERIC_KEYPAD_COLUMN3_X,
                        NUMERIC_KEYPAD_ROW1_Y, Button3Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button3Untouched[0],
                        (uint8_t *)&Button3Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[9], NUMERIC_KEYPAD_COLUMN3_X,
                        NUMERIC_KEYPAD_ROW2_Y, Button6Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button6Untouched[0],
                        (uint8_t *)&Button6Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[10], NUMERIC_KEYPAD_COLUMN3_X,
                        NUMERIC_KEYPAD_ROW3_Y, Button9Untouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&Button9Untouched[0],
                        (uint8_t *)&Button9Touched[0]);
    LCD_initButtonImage(&numKeypadButtons[11], NUMERIC_KEYPAD_COLUMN3_X,
                        NUMERIC_KEYPAD_ROW4_Y, ButtonPoundUntouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&ButtonPoundUntouched[0],
                        (uint8_t *)&ButtonPoundTouched[0]);

    // Initialize mode keypad buttons
    LCD_initButtonImage(&modeKeypadButtons[0], MODE_KEYPAD_ENDCALL_X,
                        NUMERIC_KEYPAD_ROW4_Y, ButtonEndCallUntouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&ButtonEndCallUntouched[0],
                        (uint8_t *)&ButtonEndCallTouched[0]);
    LCD_initButtonImage(&modeKeypadButtons[1], MODE_KEYPAD_HEADSET_X,
                        NUMERIC_KEYPAD_ROW4_Y, ButtonHeadsetUntouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&ButtonHeadsetUntouched[0],
                        (uint8_t *)&ButtonHeadsetTouched[0]);
    LCD_initButtonImage(&modeKeypadButtons[2], MODE_KEYPAD_MUTE_X,
                        NUMERIC_KEYPAD_ROW4_Y, ButtonMuteUntouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&ButtonMuteUntouched[0],
                        (uint8_t *)&ButtonMuteTouched[0]);
    LCD_initButtonImage(&modeKeypadButtons[3], MODE_KEYPAD_SPEAKER_X,
                        NUMERIC_KEYPAD_ROW4_Y, ButtonSpeakerUntouched_length,
                        BUTTON_IMAGE_BYTES_PER_ROW,
                        (uint8_t *)&ButtonSpeakerUntouched[0],
                        (uint8_t *)&ButtonSpeakerTouched[0]);

    // Initialize volume slider
    LCD_initSliderImage(&volumeSlider, 130, 155, SliderVolume_length, 360,
                        (uint8_t *)&SliderVolume[0]);

    // Initialize general purpose slider
    LCD_initSliderImage(&generalPurposeSlider, 30, 15,
                        SliderGeneralPurpose_length, 500,
                        (uint8_t *)&SliderGeneralPurpose[0]);
}

extern void LCD_drawNumKeypad(void)
{
    // Draw each number as either untouched or touched
    uint8_t buttonIndex;
    for(buttonIndex = 0; buttonIndex < NUMERIC_KEYPAD_BUTTON_COUNT;
        buttonIndex++)
    {
        if(numKeypadButtons[buttonIndex].touch &&
           !numKeypadButtons[buttonIndex].prevTouch)
        {
            Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                        numKeypadButtons[
                                                            buttonIndex].x,
                                                        numKeypadButtons[
                                                            buttonIndex].y,
                                                        numKeypadButtons[
                                                            buttonIndex].pixelCount,
                                                        numKeypadButtons[
                                                            buttonIndex].width,
                                                        numKeypadButtons[
                                                            buttonIndex].touchedImageData);
        }
        else if(!numKeypadButtons[buttonIndex].touch &&
                numKeypadButtons[buttonIndex].prevTouch)
        {
            Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                        numKeypadButtons[
                                                            buttonIndex].x,
                                                        numKeypadButtons[
                                                            buttonIndex].y,
                                                        numKeypadButtons[
                                                            buttonIndex].pixelCount,
                                                        numKeypadButtons[
                                                            buttonIndex].width,
                                                        numKeypadButtons[
                                                            buttonIndex].untouchedImageData);
        }
    }
}

extern void LCD_drawModeKeypad(void)
{
    // Update "End Call" button
    if(modeKeypadButtons[0].touch && !modeKeypadButtons[0].prevTouch)
    {
        Kitronix320x240x16_SSD2119PixelDrawImageDMA(0, modeKeypadButtons[0].x,
                                                    modeKeypadButtons[0].y,
                                                    modeKeypadButtons[0].pixelCount,
                                                    modeKeypadButtons[0].width,
                                                    modeKeypadButtons[0].touchedImageData);
    }
    else if(!modeKeypadButtons[0].touch && modeKeypadButtons[0].prevTouch)
    {
        Kitronix320x240x16_SSD2119PixelDrawImageDMA(0, modeKeypadButtons[0].x,
                                                    modeKeypadButtons[0].y,
                                                    modeKeypadButtons[0].pixelCount,
                                                    modeKeypadButtons[0].width,
                                                    modeKeypadButtons[0].untouchedImageData);
    }

    // Toggle state of mode buttons that maintain state
    uint8_t buttonIndex;
    for(buttonIndex = 1; buttonIndex < MODE_KEYPAD_BUTTON_COUNT; buttonIndex++)
    {
        if(modeKeypadButtons[buttonIndex].touch &&
           !modeKeypadButtons[buttonIndex].prevTouch)
        {
            modeKeypadButtons[buttonIndex].state =
                modeKeypadButtons[buttonIndex].state ^ true;
            if(modeKeypadButtons[buttonIndex].state)
            {
                Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                            modeKeypadButtons[
                                                                buttonIndex].x,
                                                            modeKeypadButtons[
                                                                buttonIndex].y,
                                                            modeKeypadButtons[
                                                                buttonIndex].pixelCount,
                                                            modeKeypadButtons[
                                                                buttonIndex].width,
                                                            modeKeypadButtons[
                                                                buttonIndex].touchedImageData);
            }
            else
            {
                Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                            modeKeypadButtons[
                                                                buttonIndex].x,
                                                            modeKeypadButtons[
                                                                buttonIndex].y,
                                                            modeKeypadButtons[
                                                                buttonIndex].pixelCount,
                                                            modeKeypadButtons[
                                                                buttonIndex].width,
                                                            modeKeypadButtons[
                                                                buttonIndex].untouchedImageData);
            }
        }
    }
}

extern void LCD_drawWheelButton(void)
{
    // Fill in circle on touch detect or erase fill on touch release
    if(wheelButton.touch && !wheelButton.prevTouch)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
        Graphics_fillCircle(&g_sContext, 215, 101, 13);
    }
    else if(!wheelButton.touch && wheelButton.prevTouch)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
        Graphics_fillCircle(&g_sContext, 215, 101, 13);
    }
}

extern void LCD_drawVolumeSlider(void)
{
    // Convert to position on LCD
    int32_t LCD_position = VolumeSlider_positionIndicator.xMin +
                           ((VolumeSlider_positionIndicator.xMax -
                             VolumeSlider_positionIndicator.xMin) *
                            volumeSlider.position) / 100;

    if(volumeSlider.position > volumeSlider.prevPosition)
    {
        // Draw lines to fill volume image
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
        int32_t i;
        int8_t j = 0;
        for(i = VolumeSlider_positionIndicator.xMin; i < LCD_position + 1;
            i +=
                (VolumeSlider_positionIndicator.xMax -
                 VolumeSlider_positionIndicator.xMin) / 14)
        {
            Graphics_drawLineH(&g_sContext, i, LCD_position, 177 - j);
            j++;
        }
    }
    else
    {
        // Draw lines to erase volume fill
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
        uint32_t deltaWidth =
            ((VolumeSlider_positionIndicator.xMax -
              VolumeSlider_positionIndicator.xMin) / 14);
        int32_t i;
        int8_t j = 0;
        for(i = VolumeSlider_positionIndicator.xMax; i > LCD_position; i--)
        {
            j = VolumeSlider_positionIndicator.xMax / deltaWidth -
                (i - 3) / deltaWidth;
            Graphics_drawLineV(&g_sContext, i,
                               VolumeSlider_positionIndicator.y + 8 + j,
                               VolumeSlider_positionIndicator.y - 9 +
                               VolumeSlider_positionIndicator.height);
        }
    }
}

extern void LCD_drawGPSlider(void)
{
    // Calculate LCD position from slider sensor position
    int32_t LCD_position = GeneralPurposeSlider_positionIndicator.xMin +
                           ((GeneralPurposeSlider_positionIndicator.xMax -
                             GeneralPurposeSlider_positionIndicator.xMin) *
                            generalPurposeSlider.position) / 100;
    int32_t LCD_prevPosition = GeneralPurposeSlider_positionIndicator.xMin +
                               ((GeneralPurposeSlider_positionIndicator.xMax -
                                 GeneralPurposeSlider_positionIndicator.xMin) *
                                generalPurposeSlider.prevPosition) / 100;

    // Clear old line
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y - 4);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y - 3);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y - 2);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y - 1);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 1);

    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 27);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 28);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 29);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 30);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 31);
    Graphics_drawLineH(&g_sContext, LCD_prevPosition - 1, LCD_prevPosition + 1,
                       GeneralPurposeSlider_positionIndicator.y + 32);

    // Draw new line
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y - 4);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y - 3);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y - 2);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y - 1);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 1);

    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 27);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 28);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 29);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 30);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 31);
    Graphics_drawLineH(&g_sContext, LCD_position - 1, LCD_position + 1,
                       GeneralPurposeSlider_positionIndicator.y + 32);
}

extern void LCD_drawScrollWheel(void)
{
    if(scrollWheel.position != scrollWheel.prevPosition)
    {
        // Clear old touch indicator
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
        double rads =
            (double)((float)(scrollWheel.prevPosition * 2 *
                             _PI) / (float)RESOLUTION - _PI / (float)2);
        int32_t x = (int32_t)((double)34 * cos(rads)) + 215;
        int32_t y = (int32_t)((double)34 * sin(rads)) + 101;
        Graphics_fillCircle(&g_sContext, x, y, 8);

        // Verify valid touch detected
        if(scrollWheel.position != 0xFFFF)
        {
            // Draw new touch location
            Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
            rads =
                (double)((float)(scrollWheel.position * 2 *
                                 _PI) / (float)RESOLUTION - _PI / (float)2);
            x = (int32_t)((double)34 * cos(rads)) + 215;
            y = (int32_t)((double)34 * sin(rads)) + 101;
            Graphics_fillCircle(&g_sContext, x, y, 8);
        }
    }
}

extern void LCD_drawGuardChannel(void)
{
    if(guardChannel.proximity && !guardChannel.prevProximity)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_YELLOW);
        Graphics_drawRectangle(&g_sContext, &proximity);
    }
    else if(!guardChannel.proximity && guardChannel.prevProximity)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
        Graphics_drawRectangle(&g_sContext, &proximity);
    }

    if(guardChannel.touch && !guardChannel.prevTouch)
    {
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_RED);
        Graphics_fillRectangle(&g_sContext, &GuardChannel_textBackground);
        Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
        Graphics_drawStringCentered(&g_sContext, "Guard Channel Active",
                                    AUTO_STRING_LENGTH,
                                    GUARD_CHANNEL_ACTIVE_TEXT_XSTART,
                                    GUARD_CHANNEL_ACTIVE_TEXT_YSTART,
                                    TRANSPARENT_TEXT);
    }
}

extern void LCD_drawSavedState(void)
{
    // Clear display
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_clearDisplay(&g_sContext);

    // Draw numeric keypad untouched
    uint8_t buttonIndex;
    for(buttonIndex = 0; buttonIndex < NUMERIC_KEYPAD_BUTTON_COUNT;
        buttonIndex++)
    {
        Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                    numKeypadButtons[buttonIndex].x,
                                                    numKeypadButtons[buttonIndex].y,
                                                    numKeypadButtons[buttonIndex].pixelCount,
                                                    numKeypadButtons[buttonIndex].width,
                                                    numKeypadButtons[buttonIndex].untouchedImageData);
    }

    // Draw "End Call" button untouched
    Kitronix320x240x16_SSD2119PixelDrawImageDMA(0, modeKeypadButtons[0].x,
                                                modeKeypadButtons[0].y,
                                                modeKeypadButtons[0].pixelCount,
                                                modeKeypadButtons[0].width,
                                                modeKeypadButtons[0].untouchedImageData);

    // Draw Headset, Mute, Speaker buttons in saved state
    for(buttonIndex = 1; buttonIndex < MODE_KEYPAD_BUTTON_COUNT; buttonIndex++)
    {
        if(modeKeypadButtons[buttonIndex].state)
        {
            Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                        modeKeypadButtons[
                                                            buttonIndex].x,
                                                        modeKeypadButtons[
                                                            buttonIndex].y,
                                                        modeKeypadButtons[
                                                            buttonIndex].pixelCount,
                                                        modeKeypadButtons[
                                                            buttonIndex].width,
                                                        modeKeypadButtons[
                                                            buttonIndex].touchedImageData);
        }
        else
        {
            Kitronix320x240x16_SSD2119PixelDrawImageDMA(0,
                                                        modeKeypadButtons[
                                                            buttonIndex].x,
                                                        modeKeypadButtons[
                                                            buttonIndex].y,
                                                        modeKeypadButtons[
                                                            buttonIndex].pixelCount,
                                                        modeKeypadButtons[
                                                            buttonIndex].width,
                                                        modeKeypadButtons[
                                                            buttonIndex].untouchedImageData);
        }
    }

    // Draw volume slider and restore level
    Kitronix320x240x16_SSD2119PixelDrawImageDMA(0, volumeSlider.x,
                                                volumeSlider.y,
                                                volumeSlider.pixelCount,
                                                volumeSlider.width,
                                                volumeSlider.imageData);
    // Reset prev position to force update
    volumeSlider.prevPosition = 0;
    LCD_drawVolumeSlider();

    // Draw general purpose slider and restore location
    Kitronix320x240x16_SSD2119PixelDrawImageDMA(0, generalPurposeSlider.x,
                                                generalPurposeSlider.y,
                                                generalPurposeSlider.pixelCount,
                                                generalPurposeSlider.width,
                                                generalPurposeSlider.imageData);
    LCD_drawGPSlider();

    // Draw Wheel in 3 separate parts
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
    Graphics_fillCircle(&g_sContext, 215, 101, 42);
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_BLACK);
    Graphics_fillCircle(&g_sContext, 215, 101, 24);
    Graphics_setForegroundColor(&g_sContext, GRAPHICS_COLOR_WHITE);
    Graphics_fillCircle(&g_sContext, 215, 101, 13);
}

void LCD_initButtonImage(LCD_ButtonImage *button,
                         int16_t x,
                         int16_t y,
                         uint16_t pixels,
                         uint16_t width,
                         uint8_t *untouchedImage,
                         uint8_t *touchedImage)
{
    button->touch = false;
    button->prevTouch = false;
    button->state = false;
    button->x = x;
    button->y = y;
    button->pixelCount = pixels;
    button->width = width;
    button->untouchedImageData = untouchedImage;
    button->touchedImageData = touchedImage;
}

void LCD_initSliderImage(LCD_SliderImage *slider,
                         int16_t x,
                         int16_t y,
                         uint16_t pixels,
                         uint16_t width,
                         uint8_t *image)
{
    slider->position = 0;
    slider->prevPosition = 0;
    slider->x = x;
    slider->y = y;
    slider->pixelCount = pixels;
    slider->width = width;
    slider->imageData = image;
}

void LCD_initGuardChannelImage(LCD_GuardChannelImage *guard,
                               Graphics_Rectangle *prox,
                               Graphics_Rectangle *background,
                               int32_t x,
                               int32_t y)
{
    guard->proximity = false;
    guard->prevProximity = false;
    guard->touch = false;
    guard->prevTouch = false;

    guard->proximityBackground = prox;
    guard->activeBackground = background;

    guard->x = x;
    guard->y = y;
}

void LCD_initDemoState(LCD_DemoState *state)
{
    *state = LCD_UpdateUI;
}
