/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 2.0.0.00
// Release Date: Tuesday, December 20, 2016 2:00 PM
//#############################################################################

#ifndef \
    MSP_EXP432P401R_CAPTIVATE_PHONEPANEL_BOOSTXL_K350QVG_S1_I2C_LCD_CONFIG_H_
#define \
    MSP_EXP432P401R_CAPTIVATE_PHONEPANEL_BOOSTXL_K350QVG_S1_I2C_LCD_CONFIG_H_

//*******************************************************************************
//! \file  LCD.h
//!
//! \brief This module contains code used to control/update the Kentec LCD
//!        based on received CapTIvate data
//
//*******************************************************************************

//*****************************************************************************
//! \addtogroup LCD
//! @{
//*****************************************************************************

//*******************************************************************************
// Includes
//*******************************************************************************
#include "grlib.h"
#include "imageButton.h"

//*******************************************************************************
// Defines
//*******************************************************************************

//! \brief LCD X position for the first column in the numeric keypad
#define NUMERIC_KEYPAD_COLUMN1_X        5
//! \brief LCD X position for the second column in the numeric keypad
#define NUMERIC_KEYPAD_COLUMN2_X        45
//! \brief LCD X position for the third column in the numeric keypad
#define NUMERIC_KEYPAD_COLUMN3_X        85

//! \brief LCD Y position for the first row in the numeric keypad
#define NUMERIC_KEYPAD_ROW1_Y   75
//! \brief LCD Y position for the second row in the numeric keypad
#define NUMERIC_KEYPAD_ROW2_Y   115
//! \brief LCD Y position for the third row in the numeric keypad
#define NUMERIC_KEYPAD_ROW3_Y   155
//! \brief LCD Y position for the fourth row in the numeric keypad
#define NUMERIC_KEYPAD_ROW4_Y   195

//! \brief LCD X position of the END CALL button
#define MODE_KEYPAD_ENDCALL_X   145
//! \brief LCD X position of the HEADSET button
#define MODE_KEYPAD_HEADSET_X   185
//! \brief LCD X position of the MUTE button
#define MODE_KEYPAD_MUTE_X              225
//! \brief LCD X position of the SPEAKER button
#define MODE_KEYPAD_SPEAKER_X   265

//! \brief Number of buttons in the numeric keypad
#define NUMERIC_KEYPAD_BUTTON_COUNT 12
//! \brief Number of buttons in the mode keypad
#define MODE_KEYPAD_BUTTON_COUNT 4
//! \brief Number of bytes in each row of a button image
#define BUTTON_IMAGE_BYTES_PER_ROW 62

//! \brief Minimum X position for guard channel text
#define GUARD_CHANNEL_ACTIVE_TEXT_XMIN          40
//! \brief Maximum X position of guard channel text
#define GUARD_CHANNEL_ACTIVE_TEXT_XMAX          280
//! \brief Minimum Y position of gurad channel text
#define GUARD_CHANNEL_ACTIVE_TEXT_YMIN          85
//! \brief Maximum Y position of guard channel text
#define GUARD_CHANNEL_ACTIVE_TEXT_YMAX          130

//! \brief Guard channel text X start location
#define GUARD_CHANNEL_ACTIVE_TEXT_XSTART        159
//! \brief Guard channel text Y start location
#define GUARD_CHANNEL_ACTIVE_TEXT_YSTART        105

//! \brief PI approximiation used to draw touch on wheel sensor
#define _PI (3.14159265)

//! \brief Total displayed resolution of wheel sensor
#define RESOLUTION (100)

//*******************************************************************************
// Typedefs
//*******************************************************************************

//! \brief LCD button image struct
typedef struct
{
    bool touch;
    bool prevTouch;
    bool state;
    int16_t x;
    int16_t y;
    uint16_t pixelCount;
    uint16_t width;
    uint8_t *untouchedImageData;
    uint8_t *touchedImageData;
} LCD_ButtonImage;

//! \brief LCD slider image struct
typedef struct
{
    uint16_t position;
    uint16_t prevPosition;
    int16_t x;
    int16_t y;
    uint16_t pixelCount;
    uint16_t width;
    uint8_t *imageData;
} LCD_SliderImage;

//! \brief LCD guard channel image struct
typedef struct
{
    bool proximity;
    bool prevProximity;
    bool touch;
    bool prevTouch;
    Graphics_Rectangle *proximityBackground;
    Graphics_Rectangle *activeBackground;
    int32_t x;
    int32_t y;
} LCD_GuardChannelImage;

//! \brief Wheel image struct
typedef struct
{
    uint16_t position;
    uint16_t prevPosition;
} LCD_WheelImage;

//! \brief Enumeration of the different states of the LCD demo application
typedef enum
{
    LCD_UpdateUI,
    LCD_HoldUI,
    LCD_ReleaseUI
} LCD_DemoState;

//! \brief Struct used to contain slider position indicator parameters
typedef struct Slider_PositionIndicator
{
    int32_t xMin;
    int32_t xMax;
    int32_t y;
    int32_t height;
} LCD_SliderPositionIndicator;

//*******************************************************************************
// Globals
//*******************************************************************************

//! \brief Array of structs containing numeric keypad data
extern LCD_ButtonImage numKeypadButtons[NUMERIC_KEYPAD_BUTTON_COUNT];

//! \brief Array of structs containing mode button data
extern LCD_ButtonImage modeKeypadButtons[MODE_KEYPAD_BUTTON_COUNT];

//! \brief Struct used to contain wheel button data
extern LCD_ButtonImage wheelButton;

//! \brief Struct used to contain volume slider data
extern LCD_SliderImage volumeSlider;

//! \brief Struct used to contain general purpose slider data
extern LCD_SliderImage generalPurposeSlider;

//! \brief Struct used to contain scroll wheel data
extern LCD_WheelImage scrollWheel;

//! \brief Struct containing guard channel data and graphics pointers
extern LCD_GuardChannelImage guardChannel;

//! \brief Keeps track of the demo application state
extern LCD_DemoState demoState;

//! \brief Struct defining where the position indicator for the volume
//!        slider can be drawn
extern LCD_SliderPositionIndicator VolumeSlider_positionIndicator;

//! \brief Struct defining where the position indicator for the general
//!        purpose slider can be drawn
extern LCD_SliderPositionIndicator GeneralPurposeSlider_positionIndicator;

//! \brief Rectangle drawn to show proximity detection
extern Graphics_Rectangle proximity;

//! \brief Rectangle used as a background for text that indicates guard channel active
extern Graphics_Rectangle GuardChannel_textBackground;

//! \brief The graphics context for the display and graphics library
extern Graphics_Context g_sContext;

//*******************************************************************************
// Function Prototypes
//*******************************************************************************

//! \brief Initialize the display and prepare the UI images
extern void LCD_init(void);

//! \brief Draw current state of the numeric keypad
extern void LCD_drawNumKeypad(void);

//! \brief Draw current state of mode keypad
extern void LCD_drawModeKeypad(void);

//! \brief Draw current wheel button state
extern void LCD_drawWheelButton(void);

//! \brief Draw volume slider state
extern void LCD_drawVolumeSlider(void);

//! \brief Draw general purpose slider state
extern void LCD_drawGPSlider(void);

//! \brief Draw scroll wheel state
extern void LCD_drawScrollWheel(void);

//! \brief Draw guard channel state
extern void LCD_drawGuardChannel(void);

//! \brief Draw UI in last known state
extern void LCD_drawSavedState(void);

#endif /* MSP_EXP432P401R_CAPTIVATE_PHONEPANEL_BOOSTXL_K350QVG_S1_I2C_LCD_CONFIG_H_ */

//*****************************************************************************
// Close the Doxygen group.
//! @}
//*****************************************************************************
