/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 2.0.0.00
// Release Date: Tuesday, December 20, 2016 2:00 PM
//#############################################################################

//*****************************************************************************
//! \addtogroup CAPT_CommConfig
//! @{
//*****************************************************************************

#ifndef CAPT_COMMCONFIG_H_
#define CAPT_COMMCONFIG_H_

//*****************************************************************************
//
// CAPT_INTERFACE may be defined as one of the following options:
//
//*****************************************************************************

//! \brief __CAPT_UART_INTERFACE__ sets the interface to UART
#define __CAPT_UART_INTERFACE__                                                     ( \
        1)
//! \brief __CAPT_I2C_INTERFACE__ sets the interface to I2C register mode
#define __CAPT_I2C_INTERFACE__                                                  ( \
        2)

//*****************************************************************************
//
//! CAPT_INTERFACE defines the serial driver used in the interface
//
//*****************************************************************************
#define CAPT_INTERFACE (__CAPT_UART_INTERFACE__)

//*****************************************************************************
//
//! CAPT_I2C_REGISTER_RW_BUFFER_SIZE is the size of the read/write buffer
//! used for I2C communication in bytes.
//
//*****************************************************************************
#define CAPT_I2C_REGISTER_RW_BUFFER_SIZE                (32)

//*****************************************************************************
//
//!	CAPT_QUEUE_BUFFER_SIZE defines the size of the byte queue used to store
//! incoming UART data.
//
//*****************************************************************************
#define CAPT_QUEUE_BUFFER_SIZE                                  (512)

//*****************************************************************************
//
//! MAX_TOTAL_DATA_BYTES is the amount of space reserved to store data
//! received via UART.
//
//*****************************************************************************
#define MAX_TOTAL_DATA_BYTES                                    (1024)

//*****************************************************************************
//
//! MAX_NUMBER_OF_PACKETS is the maximum number of unique data packets
//! stored in the UART data table.
//
//*****************************************************************************
#define MAX_NUMBER_OF_PACKETS (32)

#if (CAPT_INTERFACE == __CAPT_UART_INTERFACE__)
//*****************************************************************************
//
//! UART__ENABLE controls whether the UART driver is included.
//
//*****************************************************************************
#define UART__ENABLE                    (true)
//*****************************************************************************
//
//! I2CMASTER__ENABLE controls whether the I2C master driver is included
//
//*****************************************************************************
#define I2CMASTER__ENABLE               (false)
#elif (CAPT_INTERFACE == __CAPT_I2C_INTERFACE__)
#define UART__ENABLE                    (false)
#define I2CMASTER__ENABLE               (true)
#endif

#endif /* CAPT_COMMCONFIG_H_ */
//*****************************************************************************
//! Close the doxygen group
//! @}
//*****************************************************************************
