/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 2.0.0.00
// Release Date: Tuesday, December 20, 2016 2:00 PM
//#############################################################################

//*****************************************************************************
// CAPTHost_Interface.h
//*****************************************************************************
//*****************************************************************************
//! \addtogroup CAPT_Interface
//! @{
//*****************************************************************************

#ifndef \
    MSP_EXP432P401R_CAPTIVATE_PHONEPANEL_BOOSTXL_K350QVG_S1_CAPTIVATE_HOST_COMMS_CAPTHOST_INTERFACE_H_
#define \
    MSP_EXP432P401R_CAPTIVATE_PHONEPANEL_BOOSTXL_K350QVG_S1_CAPTIVATE_HOST_COMMS_CAPTHOST_INTERFACE_H_

#include "CAPTHost_ByteQueue.h"
#include "CAPTHost_DataTable.h"
#include "CAPTHost_Protocol.h"

//****************************************************************************
// Typedefs
//****************************************************************************

typedef enum
{
    //
    //! CAPT_NoError indicates no error occured
    CAPT_NoError,

    //
    //! CAPT_DataTableError indicates an error occured with a data table function
    //
    CAPT_DataTableError,

    //
    //! CAPT_ChecksumError indicates that an incorrect checksum was found
    //
    CAPT_ChecksumError,

    //
    //! CAPT_InvalidPacketTypeError indicates that an invalid or unhandled packet
    //! type was identified
    //
    CAPT_InvalidPacketTypeError
} CAPT_CommsError;

//****************************************************************************
// Function Prototypes
//****************************************************************************

//*****************************************************************************
//
//! Initializes the hardware used for the serial communication interface
//!
//! \param none
//! \return none
//
//*****************************************************************************
void CAPT_initCommInterface(void);

//*****************************************************************************
//
//! Used to get sensor packet from captivate device
//!
//! \param sensorID - The ID of the sensor for which to get data
//!
//! \returns Length of data packet, else 0
//
//*****************************************************************************
SensorData* CAPT_getSensorPacket(uint8_t sensorID);

//*****************************************************************************
//
//! Used to get cycle packet from captivate device
//!
//! \param sensorID - The ID of the sensor to which the cycle belongs
//! \param cycleID - The ID of the cycle for which to get data
//! \param numElements - The number of elements in the cycle
//!
//! \returns True if packet is found/received, else false
//
//*****************************************************************************
bool CAPT_getCyclePacket(CyclePacket *packet,
                         uint8_t sensorID,
                         uint8_t cycleID,
                         uint8_t numElements);

//*****************************************************************************
//
//! Used to get general purpose packets from captivate device via UART
//!
//! \param none
//!
//! \returns Pointer to general purpose packet
//
//*****************************************************************************
uint8_t * CAPT_getGeneralPurposePacket(void);

//*****************************************************************************
//
//! Call to determine if any packets have been received.
//!
//! \param none
//!
//! \return true if packet has been received, else false
//
//*****************************************************************************
bool CAPT_checkForInboundPacket(void);

//*****************************************************************************
//
//! Parse incoming bytes from the UART driver and identify/process valid
//! CapTIvate packets
//!
//! \param receiveQueue - Pointer to the queue to pull incoming bytes from
//! \param table - Table in which to store any packets that are found
//!
//! \return Error code from execution
//
//*****************************************************************************
CAPT_CommsError CAPT_processReceivedData(ByteQueue_Type *receiveQueue,
                                         DataTable_Type *table);

#endif /* MSP_EXP432P401R_CAPTIVATE_PHONEPANEL_BOOSTXL_K350QVG_S1_CAPTIVATE_HOST_COMMS_CAPTHOST_INTERFACE_H_ */
//*****************************************************************************
// Close the Doxygen group.
//! @}
//*****************************************************************************
