/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//*****************************************************************************
// UART.c
//*****************************************************************************
//*****************************************************************************
//! \addtogroup UART
//! @{
//*****************************************************************************
#include "UART.h"

#if (UART__ENABLE == true)

//*****************************************************************************
//
//! var UARTPort stores a pointer to the UART port configuration
//! structure that was passed to the UART_openPort function.  The UART
//! driver does not modify this structure.
//
//*****************************************************************************
const UART_PortType *UART_Host_Port;

//*****************************************************************************
//
//! var UARTStatus stores the current status of the UART port driver.
//
//*****************************************************************************
volatile uint8_t UARTStatus;

void UART_openPort(const UART_PortType *port)
{
    UART_closePort();
    UART_Host_Port = port;

    MAP_UART_initModule(
        __EUSCI_A_PERIPHERAL__,
        (eUSCI_UART_Config*)&(UART_Host_Port->peripheralParameters)
        );
    MAP_UART_enableModule(__EUSCI_A_PERIPHERAL__);
    MAP_UART_clearInterruptFlag(
        __EUSCI_A_PERIPHERAL__,
        EUSCI_A_UART_RECEIVE_INTERRUPT_FLAG
        );
    MAP_UART_enableInterrupt(
        __EUSCI_A_PERIPHERAL__,
        EUSCI_A_UART_RECEIVE_INTERRUPT
        );

    UARTStatus = UARTIsIdle;
}

void UART_closePort(void)
{
    UARTStatus = UARTIsClosed;
    MAP_UART_disableModule(__EUSCI_A_PERIPHERAL__);
}

uint8_t UART_getPortStatus(void)
{
    return(UARTStatus);
}

//*****************************************************************************
//
//! UART Interrupt Service Routine
//
//*****************************************************************************
void UART_ISR(void)
{
    uint8_t errors = 0;
    uint8_t data;

    // If receive flag is set
    if(UCA2IFG & UCRXIFG)
    {
        UCA2IFG &= ~UCRXIFG;
        errors = MAP_UART_queryStatusFlags(
            __EUSCI_A_PERIPHERAL__,
            UART__ERROR_MASK
            );

        // Store received data
        data = MAP_UART_receiveData(__EUSCI_A_PERIPHERAL__);
        errors |= MAP_UART_queryStatusFlags(
            __EUSCI_A_PERIPHERAL__,
            EUSCI_A_UART_OVERRUN_ERROR
            );

        // Call receive callback function if it exists
        if(UART_Host_Port->receiveCallback != 0)
        {
            if(UART_Host_Port->receiveCallback(data) == true)
            {
                __nop();
            }
        }
        // If errors occured call any existing error callback functions
        if(errors > 0)
        {
            if(UART_Host_Port->errorCallback != 0)
            {
                if(UART_Host_Port->errorCallback(errors) == true)
                {
                    __nop();
                }
            }
        }
    }
}

#endif /* UART__ENABLE==true */
//*****************************************************************************
//! Close the doxygen group
//! @}
//*****************************************************************************
