/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//#############################################################################
// TI Release: 1.0.0.00
// Release Date: Friday, August 12, 2016 8:54 AM
//#############################################################################

//*****************************************************************************
// CAPTHost_Protocol.c
//*****************************************************************************

#include <CAPTHost_Protocol.h>
#include <stdlib.h>

bool CAPT_parseQueueForPacket(ByteQueue_Type *receiveQueue,
                              GeneralPacketType *packet)
{
    static int8_t currPacketIndex = -1;
    static bool stuffedByteDetected = false;
    bool checksumVerified = false;
    uint8_t pulledByte = 0;

    //
    // If no packet has started framing, check to see if
    // bytes are ready to be checked
    //
    if(currPacketIndex < 0)
    {
        while(CAPT_getByteQueueSize(receiveQueue) > CYCLE_PACKET_MAX_SIZE)
        {
            CAPT_pullFromByteQueue(receiveQueue, &pulledByte);
            if(pulledByte != PROTOCOL_SYNC)
            {
                __nop();
                continue;
            }
            CAPT_pullFromByteQueue(receiveQueue, &pulledByte);
            if(pulledByte == PROTOCOL_SYNC)
            {
                __nop();
                continue;
            }
            CAPT_pullFromByteQueue(receiveQueue, &pulledByte);
            packet->length = pulledByte;
            if(packet->length > MAX_PACKET_LENGTH)
            {
                currPacketIndex = -1;
                return(false);
            }
            currPacketIndex = 0;
            break;
        }
    }

    //
    // If packet started, start framing
    //
    if(currPacketIndex >= 0)
    {
        while(CAPT_getByteQueueSize(receiveQueue) > 0)
        {
            CAPT_pullFromByteQueue(receiveQueue, &pulledByte);
            packet->payload[currPacketIndex] = pulledByte;
            if(stuffedByteDetected == true)
            {
                if(packet->payload[currPacketIndex]
                   == PROTOCOL_SYNC)
                {
                    currPacketIndex++;
                    stuffedByteDetected = false;
                }
                else
                {
                    currPacketIndex = -1;
                    stuffedByteDetected = false;
                    return(false);
                }
            }
            else if(packet->payload[currPacketIndex]
                    == PROTOCOL_SYNC)
            {
                stuffedByteDetected = true;
            }
            else
            {
                currPacketIndex++;
            }

            if(currPacketIndex == packet->length)
            {
                currPacketIndex = -1;
                checksumVerified = CAPT_verifyChecksum(packet->payload,
                                                       packet->length);
                break;
            }
        }
    }

    return(checksumVerified);
}

bool CAPT_verifyChecksum(uint8_t *data,
                         uint8_t length)
{
    uint16_t calculated, expected;
    uint8_t index;

    // Extract expected checksum from last two bytes
    expected = (data[length - 2] | (data[length - 1] << 8));

    // Calculate observed checksum
    calculated = 0;
    for(index = 0; index < length - 2; index++)
    {
        calculated += data[index];
    }

    return(expected == calculated);
}
