/* --COPYRIGHT--,BSD
 * Copyright (c) 2016, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * --/COPYRIGHT--*/
//*****************************************************************************
// I2CMaster.h
//
// \version 0.03.00.00
// Released on Thu, Aug 27, 2015  4:24:33 PM
//
//*****************************************************************************
//*****************************************************************************
//! \addtogroup I2CMaster
//! @{
//*****************************************************************************
#ifndef I2CMASTER_H_
#define I2CMASTER_H_

#include <driverlib.h>
#include "../CAPTHost_CommConfig.h"
#include "I2CMaster_Definitions.h"

#if (I2CMASTER__ENABLE == true)

//*****************************************************************************
//
//! typedef I2CMasterError is the enumeration of errors returned by the
//! I2C master driver
//
//*****************************************************************************
enum
{
    I2CMaster_noError = 0,
    I2CMaster_unavailableError,
    I2CMaster_slaveNackError,
    I2CMaster_busTimeoutError
};
typedef uint8_t I2CMasterError;

//*****************************************************************************
//
//! \typedef I2C_PortType defines the port definition that the user must
//! provide when instantiating this driver.  This structure is read-only from
//! the context of the driver, and may be placed in read-only memory, such as
//! the C CONST section, if desired.
//
//*****************************************************************************
typedef struct
{
    //
    //! eUSCI_B initialization parameters.  This structure
    //! is defined in the MSP432 peripheral driver library.
    //
    eUSCI_I2C_MasterConfig peripheralParameters;
} I2C_PortType;

//*****************************************************************************
//
//! \brief Open the I2C master driver for operation.
//
//! \param port contains the I2C settings for configuring the EUSCI B peripheral
//
//! \return none
//
//*****************************************************************************
void I2CMaster_open(const I2C_PortType *port);

//*****************************************************************************
//
//! \brief Close the I2C master driver.
//
//! \param none
//
//! \return none
//
//*****************************************************************************
void I2CMaster_close(void);

//*****************************************************************************
//
//! \brief Write a buffer to an I2C slave
//
//! \param ui8Addr is the address of the slave
//! \param pData is a pointer to the data to write
//! \param ui8Cnt is the length of pData in bytes
//
//! \return true if the slave nack'ed, else false.
//
//*****************************************************************************
I2CMasterError I2CMaster_writeBuffer(uint8_t addr,
                                     uint8_t *pData,
                                     uint8_t ui8Cnt);

//*****************************************************************************
//
//! \brief Read to a buffer from an I2C slave
//
//! \param ui8Addr is the address of the slave
//! \param ui8Reg is the sub-register on the slave device to read from
//! \param ui8Cnt specifies the number of bytes to read from the slave.
//
//! \return true if the slave nack'ed, else false.
//
//*****************************************************************************
I2CMasterError I2CMaster_readBuffer(uint8_t ui8Addr,
                                    uint8_t *data,
                                    uint8_t cnt);

#endif  /* I2CMASTER__ENABLE==true */

#endif  /* I2CMASTER_H_ */
//*****************************************************************************
//! Close the doxygen group
//! @}
//*****************************************************************************
